@@ -16,6 +16,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include <config.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
@@ -1014,6 +1015,9 @@ xchat_get_info (xchat_plugin *ph, const char *id)
 	case 0x14f51cd8: /* version */
 		return VERSION;
 
+	case 0x506d600b: /* native win_ptr */
+		return fe_gui_info_ptr (sess, 0);
+
 	case 0x6d3431b5: /* win_status */
 		switch (fe_gui_info (sess, 0))	/* check window status */
 		{
@@ -1111,6 +1115,7 @@ xchat_list_get (xchat_plugin *ph, const char *name)
 		{
 			list->type = LIST_USERS;
 			list->head = list->next = userlist_flat_list (ph->context);
+			fe_userlist_set_selected (ph->context);
 			break;
 		}	/* fall through */
 
@@ -1176,7 +1181,7 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 	};
 	static const char * const users_fields[] =
 	{
-		"iaway", "shost", "tlasttalk", "snick", "sprefix", NULL
+		"iaway", "shost", "tlasttalk", "snick", "sprefix", "iselected", NULL
 	};
 	static const char * const list_of_lists[] =
 	{
@@ -1353,7 +1358,9 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		case 0xd1b:	/* id */
 			return ((struct session *)data)->server->id;
 		case 0x5cfee87:	/* flags */
-			tmp = ((struct session *)data)->server->have_whox;   /* bit 4 */
+			tmp = ((struct session *)data)->server->have_idmsg;   /* bit 5 */
+			tmp <<= 1;
+			tmp |= ((struct session *)data)->server->have_whox;  /* 4 */
 			tmp <<= 1;
 			tmp |= ((struct session *)data)->server->end_of_motd;/* 3 */
 			tmp <<= 1;
@@ -1386,6 +1393,8 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		{
 		case 0x2de2ee:	/* away */
 			return ((struct User *)data)->away;
+		case 0x4705f29b: /* selected */
+			return ((struct User *)data)->selected;
 		}
 		break;
 
