@@ -1,7 +1,7 @@
 /*
  * pixmaps.h - helper functions for pixmaps
  *
- * Copyright (C) 2004 xchat-gnome team
+ * Copyright (C) 2004-2005 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
 #ifndef XCHAT_GNOME_PIXMAPS_H
 #define XCHAT_GNOME_PIXMAPS_H
 
-#include <gnome.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 extern GdkPixbuf *pix_purple;
 extern GdkPixbuf *pix_red;
@@ -34,12 +34,6 @@ extern GdkPixbuf *pix_newdata;
 extern GdkPixbuf *pix_nicksaid;
 extern GdkPixbuf *pix_msgsaid;
 
-extern GdkPixbuf *pix_prefs_irc;
-extern GdkPixbuf *pix_prefs_colors;
-extern GdkPixbuf *pix_prefs_dcc;
-extern GdkPixbuf *pix_prefs_networks;
-extern GdkPixbuf *pix_prefs_plugins;
-
 extern void pixmaps_init (void);
 
 #endif
