@@ -1,7 +1,7 @@
 /*
  * plugins.h - handle (auto)loading and unloading of plugins
  *
- * Copyright (C) 2005 David Trowbridge
+ * Copyright (C) 2004-2005 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,8 +19,8 @@
  *
  */
 
-#include "../common/xchat.h"
 #include "navigation-tree.h"
+#include "../common/xchat.h"
 
 #ifndef XCHAT_GNOME_PLUGINS_H
 #define XCHAT_GNOME_PLUGINS_H
@@ -32,19 +32,17 @@
  */
 struct _xchat_gnome_plugin
 {
-	GtkWidget *(*xg_get_main_window) ();
-	GtkTreeModel *(*xg_get_chan_list) ();
+	GtkWidget    *(*xg_get_main_window) ();
+	GtkTreeModel *(*xg_get_chan_list)   ();
+	GtkUIManager *(*xg_get_ui_manager)  ();
 };
 #endif
 
 extern GSList *enabled_plugins;
 
-void plugins_initialize ();
-void autoload_plugins ();
-int unload_plugin (char *filename);
-char *load_plugin (session * sess, char *filename, char *arg);
+void  plugins_initialize (void);
+void  autoload_plugins   (void);
+int   unload_plugin      (char *filename);
+char *load_plugin        (session * sess, char *filename, char *arg, gboolean script, gboolean autoload);
 
 #endif
-/*** The End ***/
-/* vim:ts=3:sw=3
- */
